# == Synopsis
# vortex00.rb -- solution in ruby to level 00 of the Vortex Wargame
#                located at http://www.pulltheplug.org
#
# Your goal is to connect to port 5842 on vortex.labs.pulltheplug.org 
# and read in 4 unsigned integers. Add these integers together and 
# send back the results to get a username and password for level 1. 
# Note that vortex is on an x86 machine (meaning, a little endian 
# architecture).
#
# == Usage
# ruby vortex00.rb [ -h | --help ] [ -v | --version ]
# 
# == Author
# Beau Grantham
# beau@thedarkmere.net
# 
# == Version
# 0x2 2006/05/03

require 'socket'
require 'rdoc/usage'
require 'optparse'

# RDoc
opts = OptionParser.new
opts.on("-h", "--help") { RDoc::usage }
opts.on("-v", "--version") { RDoc::usage('version') }
opts.parse(ARGV) rescue RDoc::usage('usage')

server = "69.55.233.82"
port   = "5842"
result = [0]

print "Connecting to #{server}:#{port}... "
sock = TCPSocket.new(server, port)
puts  "Success!"

print "Reading data... "
# Unsigned int is 4 bytes
4.times { result[0] += sock.read(4).unpack('l').first }
puts  (4*4).to_s + " bytes read."

# The result will on occasion exceed 2^32 and throw a
# RangeError exception. We should fake an overflow by
# subtracting out 2^32 from the value.

begin
  result[0] = result.pack('l')
rescue RangeError
  result[0] -= 2**32
  result[0] = result.pack('l')
end

print "Sending result... "
sock.puts(result[0])
puts  "Success!"

print sock.read(1024)

